# coding: utf-8
# Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20181201


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlFirewallConfig(object):
    """
    The SQL Firewall related configurations.
    """

    #: A constant which can be used with the status property of a SqlFirewallConfig.
    #: This constant has a value of "ENABLED"
    STATUS_ENABLED = "ENABLED"

    #: A constant which can be used with the status property of a SqlFirewallConfig.
    #: This constant has a value of "DISABLED"
    STATUS_DISABLED = "DISABLED"

    #: A constant which can be used with the violation_log_auto_purge property of a SqlFirewallConfig.
    #: This constant has a value of "ENABLED"
    VIOLATION_LOG_AUTO_PURGE_ENABLED = "ENABLED"

    #: A constant which can be used with the violation_log_auto_purge property of a SqlFirewallConfig.
    #: This constant has a value of "DISABLED"
    VIOLATION_LOG_AUTO_PURGE_DISABLED = "DISABLED"

    #: A constant which can be used with the exclude_job property of a SqlFirewallConfig.
    #: This constant has a value of "EXCLUDED"
    EXCLUDE_JOB_EXCLUDED = "EXCLUDED"

    #: A constant which can be used with the exclude_job property of a SqlFirewallConfig.
    #: This constant has a value of "INCLUDED"
    EXCLUDE_JOB_INCLUDED = "INCLUDED"

    def __init__(self, **kwargs):
        """
        Initializes a new SqlFirewallConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param status:
            The value to assign to the status property of this SqlFirewallConfig.
            Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param violation_log_auto_purge:
            The value to assign to the violation_log_auto_purge property of this SqlFirewallConfig.
            Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type violation_log_auto_purge: str

        :param exclude_job:
            The value to assign to the exclude_job property of this SqlFirewallConfig.
            Allowed values for this property are: "EXCLUDED", "INCLUDED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type exclude_job: str

        :param time_status_updated:
            The value to assign to the time_status_updated property of this SqlFirewallConfig.
        :type time_status_updated: datetime

        """
        self.swagger_types = {
            'status': 'str',
            'violation_log_auto_purge': 'str',
            'exclude_job': 'str',
            'time_status_updated': 'datetime'
        }

        self.attribute_map = {
            'status': 'status',
            'violation_log_auto_purge': 'violationLogAutoPurge',
            'exclude_job': 'excludeJob',
            'time_status_updated': 'timeStatusUpdated'
        }

        self._status = None
        self._violation_log_auto_purge = None
        self._exclude_job = None
        self._time_status_updated = None

    @property
    def status(self):
        """
        **[Required]** Gets the status of this SqlFirewallConfig.
        Specifies if the firewall is enabled or disabled on the target database.

        Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this SqlFirewallConfig.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this SqlFirewallConfig.
        Specifies if the firewall is enabled or disabled on the target database.


        :param status: The status of this SqlFirewallConfig.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def violation_log_auto_purge(self):
        """
        **[Required]** Gets the violation_log_auto_purge of this SqlFirewallConfig.
        Specifies whether Data Safe should automatically purge the violation logs
        from the database after collecting the violation logs and persisting on Data Safe.

        Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The violation_log_auto_purge of this SqlFirewallConfig.
        :rtype: str
        """
        return self._violation_log_auto_purge

    @violation_log_auto_purge.setter
    def violation_log_auto_purge(self, violation_log_auto_purge):
        """
        Sets the violation_log_auto_purge of this SqlFirewallConfig.
        Specifies whether Data Safe should automatically purge the violation logs
        from the database after collecting the violation logs and persisting on Data Safe.


        :param violation_log_auto_purge: The violation_log_auto_purge of this SqlFirewallConfig.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(violation_log_auto_purge, allowed_values):
            violation_log_auto_purge = 'UNKNOWN_ENUM_VALUE'
        self._violation_log_auto_purge = violation_log_auto_purge

    @property
    def exclude_job(self):
        """
        Gets the exclude_job of this SqlFirewallConfig.
        Specifies whether the firewall should include or exclude the database internal job activities.

        Allowed values for this property are: "EXCLUDED", "INCLUDED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The exclude_job of this SqlFirewallConfig.
        :rtype: str
        """
        return self._exclude_job

    @exclude_job.setter
    def exclude_job(self, exclude_job):
        """
        Sets the exclude_job of this SqlFirewallConfig.
        Specifies whether the firewall should include or exclude the database internal job activities.


        :param exclude_job: The exclude_job of this SqlFirewallConfig.
        :type: str
        """
        allowed_values = ["EXCLUDED", "INCLUDED"]
        if not value_allowed_none_or_none_sentinel(exclude_job, allowed_values):
            exclude_job = 'UNKNOWN_ENUM_VALUE'
        self._exclude_job = exclude_job

    @property
    def time_status_updated(self):
        """
        Gets the time_status_updated of this SqlFirewallConfig.
        The most recent time when the firewall status is updated, in the format defined by RFC3339.


        :return: The time_status_updated of this SqlFirewallConfig.
        :rtype: datetime
        """
        return self._time_status_updated

    @time_status_updated.setter
    def time_status_updated(self, time_status_updated):
        """
        Sets the time_status_updated of this SqlFirewallConfig.
        The most recent time when the firewall status is updated, in the format defined by RFC3339.


        :param time_status_updated: The time_status_updated of this SqlFirewallConfig.
        :type: datetime
        """
        self._time_status_updated = time_status_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
